@@ -2,6 +2,7 @@
 
 #include <glib.h>
 #include "rsvg.h"
+#include "rsvg-compat.h"
 #include "test-utils.h"
 
 typedef struct _FixtureData
@@ -39,7 +40,7 @@ main (int argc, char *argv[])
     gint i;
     int result;
 
-    g_type_init ();
+    RSVG_G_TYPE_INIT;
     g_test_init (&argc, &argv, NULL);
 
     for (i = 0; i < n_fixtures; i++)
